import * as React from 'react';
import {observer} from "mobx-react-lite";
import {ModelInput, useModelContext} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {Box, Paper} from "@material-ui/core";
import Typography from "@material-ui/core/Typography";
import {InterfaceType} from "../../../stores/InterfaceConfigStore";
import ReactTable, {Column} from "react-table";
import {SessionTypeBox} from "../SessionTypeBox";
import {InterfaceConfigExampleAccordion} from "../InterfaceConfigExampleAccordion";
import {InterfaceConfigKeys} from "../../../stores/Dcs2restConfigStore";

type BaseInterfaceConfigFormProps = {
    columns: Column<any>[];
    interfaceType: InterfaceType;
    interfaceConfigKey: InterfaceConfigKeys;
    rangeKeys: Readonly<{
        min: string,
        max: string
    }>;
    buildTableData: (arr: any[]) => Record<string, unknown>[];
    defaultSorted?: ReadonlyArray<{id: string, desc: boolean}>;
};

export const BaseInterfaceConfigForm: React.FunctionComponent<BaseInterfaceConfigFormProps> = observer(({
                                                                                                            columns,
                                                                                                            interfaceType,
                                                                                                            interfaceConfigKey,
                                                                                                            rangeKeys  ,
                                                                                                            buildTableData,
                                                                                                            defaultSorted}) => {

    const model = useModelContext();

    const tableData = React.useMemo(() => {
        if(!model.viewModel.interface_configs) { return []; }

        return buildTableData(model.viewModel.interface_configs[interfaceConfigKey]);
    }, [interfaceConfigKey, model.viewModel.interface_configs]);

    // NOTE: ModelInput uses parent Dcs2restConfig model

    return (
        <Box>
            <Box mt={2} display={'flex'} alignItems={'center'} justifyContent={'space-between'}>
                <SessionTypeBox interfaceType={interfaceType}/>
                <Box ml={6}>
                    <Paper variant={'outlined'}>
                        <Box p={2}>
                            <Box display={'flex'} alignItems={'center'} justifyContent={'center'}>
                                <Typography>{t`XStatus Range`}</Typography>
                            </Box>
                            <Box mt={2} display={'flex'} alignItems={'center'} justifyContent={'center'}>
                                <Box ml={2} flex={'auto'}>
                                    <ModelInput name={rangeKeys.min}/>
                                </Box>
                                <Box ml={2}>
                                    <Typography>{t`to`}</Typography>
                                </Box>
                                <Box ml={2} flex={'auto'}>
                                    <ModelInput name={rangeKeys.max}/>
                                </Box>
                            </Box>
                        </Box>
                    </Paper>
                </Box>
            </Box>
            <Box mt={1}>
                <InterfaceConfigExampleAccordion interfaceType={interfaceType}/>
            </Box>
            <Box mt={3}>
                <ReactTable
                    data={tableData}
                    columns={columns}
                    showPagination={false}
                    defaultPageSize={tableData.length}
                    sortable={false}
                    defaultSorted={defaultSorted}
                />
            </Box>
        </Box>
    );
});
