import * as React from 'react';
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {Column} from "react-table";
import {BaseInterfaceConfigForm} from "./BaseInterfaceConfigForm";
import {useXStatusColumn} from "../useXStatusColumn";

type EventInterfaceConfigFormProps = {
};

const errortype_to_enum = ['Unknown', 'Info', 'Alarm', 'Error', 'Warning']

export const EventInterfaceConfigForm: React.FunctionComponent<EventInterfaceConfigFormProps> = observer(() => {
    const buildTableData = (arr: any[]) => {
        return arr.map((modelDatum) => {
            const dataJson = modelDatum.data;
            return {
                id: modelDatum.id,
                x_status: modelDatum.x_status,
                error_type: errortype_to_enum[dataJson.type]
            };
        });
    }

    const columns = [
        useXStatusColumn('event'),
        {
            Header: t`Error Type`,
            accessor: 'error_type',
            sortable: true
        }
    ] as Column[];


    return <BaseInterfaceConfigForm
        columns={columns}
        interfaceConfigKey={'event'}
        interfaceType={'EventInterfaceConfig'}
        buildTableData={buildTableData}
        rangeKeys={{ min: 'event_min', max: 'event_max' }}
        defaultSorted={[{id: 'error_type', desc: false}]}
    />;
});
