import * as React from 'react';
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {Column} from "react-table";
import {BaseInterfaceConfigForm} from "./BaseInterfaceConfigForm";
import {useXStatusColumn} from "../useXStatusColumn";

type MaintenanceInterfaceConfigFormProps = {
};

const type_to_enum = ['Unknown', 'Counter', 'Date', 'Time Period', 'Event']
const status_to_enum = ['Raised', 'Acknowledge', 'Finished']
export const MaintenanceInterfaceConfigForm: React.FunctionComponent<MaintenanceInterfaceConfigFormProps> = observer(() => {
    const buildTableData = (arr: any[]) => {
        return arr.map((modelDatum) => {
            const dataJson = modelDatum.data;
            return {
                id: modelDatum.id,
                x_status: modelDatum.x_status,
                type: type_to_enum[dataJson.type],
                status: status_to_enum[dataJson.status]
            };
        });
    }

    const columns = [
        useXStatusColumn('maintenance'),
        {
            Header: t`Type`,
            accessor: 'type',
            sortable: true
        },
        {
            Header: t`Status`,
            accessor: 'status',
            sortable: true
        }
    ] as Column[];


    return <BaseInterfaceConfigForm
        columns={columns}
        interfaceConfigKey={'maintenance'}
        interfaceType={'MaintenanceInterfaceConfig'}
        buildTableData={buildTableData}
        rangeKeys={{ min: 'maintenance_min', max: 'maintenance_max' }}
        defaultSorted={[{id: 'type', desc: false}, {id: 'status', desc: false}]}
    />;
});
