import * as React from 'react';
import {t} from "@lingui/macro";
import {InputField, useModelContext} from "@rx-suite/ui";
import {InterfaceConfigKeys} from "../../stores/Dcs2restConfigStore";

export const useXStatusColumn = (interfaceConfigKey: InterfaceConfigKeys) => {
    const model = useModelContext();

    return {
        Header: t`XStatus`,
        accessor: 'x_status',
        Cell: (cellInfo: { original: { id: number, data: any, x_status: number}, value: number }) => {
            if (!cellInfo || cellInfo.value == null) {
                return null;
            }

            const originalRow = cellInfo.original;
            if (!originalRow || originalRow.id == null) {
                return null;
            }

            if (!model.viewModel.interface_configs) {
                return null;
            }

            const index = model.viewModel.interface_configs[interfaceConfigKey].findIndex((obj) => obj.id === cellInfo.original.id);

            const x_status = model.viewModel.interface_configs[interfaceConfigKey][index].x_status;
            const error_too_small = x_status < model.viewModel[`${interfaceConfigKey}_min`]
           const error_too_big = x_status > model.viewModel[`${interfaceConfigKey}_max`]

            const error_hint = () => {
                if(error_too_small) {
                    return 'X Status value less than minimum'
                }
                if(error_too_big) {
                    return 'X Status value greater than maximum'
                }
                return ''
            }

            return (
                <InputField
                    type={"number"}
                    onChange={(e) => {
                        model.viewModel.nestedAssignment(`interface_configs.${interfaceConfigKey}.${index}.x_status`, e.target.value)}
                    }
                    value={x_status}
                    error={error_too_small || error_too_big}
                    helperText={error_hint()}
                />
            );
        }
    };
};
