import * as React from 'react';
import {observer} from "mobx-react-lite";
import {ModelActionButton, useModelContext} from "@rx-suite/ui";
import {Box, makeStyles, Typography} from '@material-ui/core';
import {t} from "@lingui/macro";
import {DcsConfigModel} from "../../stores/DcsConfigStore";
import {Replay} from "@material-ui/icons";

const useStyles = makeStyles((theme) => ({
    name: {
        fontSize: '2.5rem'
    },
    identifier: {
        fontSize: '1.25rem',
        marginTop: theme.spacing(-2),
        color: '#666666'
    }
}));

export const DcsConfigHeader: React.FunctionComponent = observer(() => {
    const classes = useStyles();

    const model = useModelContext() as DcsConfigModel;

    if(model.isNew){
        return null;
    }

    return (
        <Box mb={1} display={'flex'} justifyContent={'space-between'}>
            <Box>
                <Typography className={classes.name}>{`${model.name}`}</Typography>
                <Typography className={classes.identifier}>{`${model.ip}:${model.port}`}</Typography>
            </Box>
            <ModelActionButton
                name={'reinitialize'}
                text={t`Reinitialize`}
                startIcon={<Replay/>}
                color={'secondary'}
            />
        </Box>
    )
});
