import * as React from 'react';
import {observer} from "mobx-react-lite";
import {t} from '@lingui/macro';
import {Grid, makeStyles} from "@material-ui/core";
import {Alert} from "@material-ui/lab";
import Typography from "@material-ui/core/Typography";
import {ErrorData} from "../../stores/DcsTraceStore";
import Box from "@material-ui/core/Box";

type DcsErrorDataProps = {
    error: ErrorData;
}

const useStyles = makeStyles((theme) => ({
    label: {
        marginRight: theme.spacing(1),
        fontWeight: 'bold'
    },
    labelContainer: {
        maxWidth: '200px'
    }
}));

export const DcsErrorData: React.FunctionComponent<DcsErrorDataProps> = observer(({error}) => {
    const classes = useStyles();

    const valOrFalse = (val: boolean | null): boolean => {
        return (val === null || val === undefined) ? false : val;
    }

    const boolToString = (val : boolean) => {
        return val ? 'TRUE' : 'FALSE';
    }

    const errMsg = error['message'] ? error['message'] : t`Unknown Error.`;
    const failToFetch = valOrFalse(error['failToFetch']);
    const timeout = valOrFalse(error['timeout']);
    const jobDoesNotExist = valOrFalse(error['jobDoesNotExist']);

    return (
        <div>
            <Alert severity='error'>
                {errMsg}
            </Alert>
            <Box mt={1}>
            <Typography variant={'h6'}>Debug Information</Typography>
                <Grid container direction={'column'} className={classes.labelContainer}>
                    <div>
                        <Grid container alignItems={'center'} justifyContent={'space-between'}>
                            <Typography variant={'subtitle2'} className={classes.label}>Connection Failure</Typography>
                            <Typography variant={'subtitle1'}>{boolToString(failToFetch)}</Typography>
                        </Grid>
                        <Grid container alignItems={'center'} justifyContent={'space-between'}>
                            <Typography variant={'subtitle2'} className={classes.label}>Socket Timeout</Typography>
                            <Typography variant={'subtitle1'}>{boolToString(timeout)}</Typography>
                        </Grid>
                        <Grid container alignItems={'center'} justifyContent={'space-between'}>
                            <Typography variant={'subtitle2'} className={classes.label}>Job does not Exist</Typography>
                            <Typography variant={'subtitle1'}>{boolToString(jobDoesNotExist)}</Typography>
                        </Grid>
                    </div>
                </Grid>
            </Box>
        </div>
    )
});

