import * as React from 'react';
import {observer} from "mobx-react-lite";
import {Conditional, IfFalse, IfTrue, ModelProvider} from "@rx-suite/ui";
import {DcsTraceModel} from "../../stores/DcsTraceStore";
import {
    Dialog,
    DialogActions,
    DialogContent,
    DialogTitle,
    Divider,
    Grid,
    IconButton,
    makeStyles
} from "@material-ui/core";
import {Trans} from "@lingui/macro";
import {SystemSettingModel, SystemSettingStore} from "@rx-suite/stores";
import Typography from "@material-ui/core/Typography";
import {StatusIndicator} from "../generic/StatusIndicator";
import Box from "@material-ui/core/Box";
import {DcsTagsTable} from "./DcsTagsTable";
import JsonFormatter from "react-json-formatter";
import {Close} from "@material-ui/icons";
import {DcsErrorData, ErrorData} from "./DcsErrorData";

type DcsTraceDialogProps = {
    model: DcsTraceModel | undefined;
    open: boolean;
    handleClose: () => void;

}

const useStyles = makeStyles((theme) => ({
    textBold: {
        fontWeight: 'bold'
    }
}));

export const DcsTraceDialog: React.FunctionComponent<DcsTraceDialogProps> = observer(({model, open, handleClose}) => {
    const classes = useStyles();

    const settings = SystemSettingStore.selectedModel as SystemSettingModel;

    if(!model){
        return null;
    }

    return (
        <ModelProvider value={model}>
            <Dialog open={open} onClose={handleClose} aria-labelledby="form-dialog-title" maxWidth={'md'} fullWidth>
                <Grid container justifyContent={'space-between'}>
                    <DialogTitle id="form-dialog-title">Job {model.job_number} at {settings ? settings.printTimeDate(model.created_at) : model.created_at}</DialogTitle>
                    <DialogActions>
                        <IconButton onClick={handleClose}>
                            <Close/>
                        </IconButton>
                    </DialogActions>
                </Grid>
                <DialogContent>
                    <Box mb={1}>
                        <Grid container alignItems={'center'}>
                            <Typography variant={'subtitle1'} className={classes.textBold}><Trans>Status</Trans></Typography>
                            <Box ml={1}>
                                <StatusIndicator success={model.successful}/>
                            </Box>
                        </Grid>
                    </Box>
                    <Conditional condition={model.successful}>
                        <IfTrue>
                            <Box mb={1}>
                                <Typography variant={'subtitle1'} className={classes.textBold}><Trans>Response</Trans></Typography>
                                <div>
                                    <DcsTagsTable tagData={model.resolveParsedData}/>
                                </div>
                            </Box>
                        </IfTrue>
                        <IfFalse>
                            <Box mb={1}>
                                <DcsErrorData error={model.resolveErrorData as ErrorData}/>
                            </Box>
                        </IfFalse>
                    </Conditional>
                    <Conditional condition={model.raw_data !== null}>
                        <Divider/>
                        <Box mb={1}>
                            <Typography variant={'subtitle1'} className={classes.textBold}><Trans>Raw Response</Trans></Typography>
                            <div>
                                {model.raw_data && <JsonFormatter
                                    json={model.raw_data}
                                    jsonStyle={
                                        {
                                            stringStyle: { color: 'darkgreen' },
                                            numberStyle: { color: 'blue' }
                                        }
                                    }/>}
                            </div>
                        </Box>
                    </Conditional>
                </DialogContent>
            </Dialog>
        </ModelProvider>
    )
});
