import * as React from "react";
import {observer} from "mobx-react-lite";
import {
    Dialog,
    DialogActions,
    DialogTitle,
    Grid,
    IconButton,
    DialogContent,
    makeStyles,
    DialogContentText,
} from "@material-ui/core";
import {Conditional, IfFalse, IfTrue, ModelProvider, PaddedPaper} from "@rx-suite/ui";
import {Close} from "@material-ui/icons";
import ReactTable from "react-table";
import {Dcs2restTraceModel} from "../../stores/Dcs2restTraceStore";
import {t} from "@lingui/macro"
import beautify from "xml-beautifier";
import Typography from "@material-ui/core/Typography";
import {SystemSettingModel, SystemSettingStore} from "@rx-suite/stores";

type Dcs2restTraceDialogProps = {
    model: Dcs2restTraceModel | null;
    open: boolean;
    handleClose: () => void;
}

const useStyles = makeStyles((theme) => ({
    textBold: {
        fontWeight: 'bold'
    },
    xmlFormattedText: {
        whiteSpace: 'pre-wrap'
    }
}));

export const Dcs2restTraceDialog: React.FunctionComponent<Dcs2restTraceDialogProps> = observer(({model, open, handleClose}) => {
    const classes = useStyles();

    const systemSettingModel = SystemSettingStore.selectedModel as unknown as SystemSettingModel;

    if(!model) {
        return null;
    }

    const formattedData = model.raw_data.map((str) => {
        return {message: str};
    })

    return (
        <ModelProvider value={model}>
            <Dialog open={open} onClose={handleClose} aria-labelledby="form-dialog-title" maxWidth={'md'} fullWidth>
                <Grid container justifyContent={'space-between'}>
                    <DialogTitle id="form-dialog-title">{t`Dcs 2 Rest Trace`}</DialogTitle>
                    <DialogActions>
                        <IconButton onClick={handleClose}>
                            <Close/>
                        </IconButton>
                    </DialogActions>
                </Grid><Grid container justifyContent={'space-between'}>
                <DialogContent>
                    <Conditional condition={model.success}>
                        <IfTrue>
                            <DialogContentText>{t`Target Endpoint` + `: ${model.targeted_endpoint}`}</DialogContentText>
                        </IfTrue>
                    </Conditional>
                    <Typography variant={'h6'}>
                        {t`Received at: ` +` ${systemSettingModel.printFormatDate(model.time, 'dateTime')}`}
                    </Typography>
                    <ReactTable
                        pageSize={formattedData.length}
                        showPagination={false}
                        data={formattedData}
                        columns={[
                            {
                                Header: t`Messages`,
                                accessor: 'message'
                            }
                        ]}
                    />
                    <br/>
                    <Conditional condition={model.success}>
                        <IfTrue>
                            <Typography variant={'h6'}>
                                {t`Generated XML`}
                            </Typography>
                            <PaddedPaper>
                                <Typography className={classes.xmlFormattedText}>
                                    {beautify(model.generated_payload || '')}
                                </Typography>
                            </PaddedPaper>
                        </IfTrue>
                        <IfFalse>
                            <Typography variant={'h6'} color={'error'}>{t`Error:` + ` ${model.last_error}`}</Typography>
                        </IfFalse>
                    </Conditional>
                </DialogContent>
            </Grid>
            </Dialog>
        </ModelProvider>
    )
})
