import * as React from 'react';
import {observer} from "mobx-react-lite";
import {ButtonField, makeColumn, ModelTable, useFlag, useModelContext} from "@rx-suite/ui";
import {DcsConfigModel} from "../../../stores/DcsConfigStore";
import {DcsTraceModel, DcsTraceStore} from "../../../stores/DcsTraceStore";
import {t} from '@lingui/macro';
import {SystemSettingModel, SystemSettingStore} from "@rx-suite/stores";
import {Pageview} from "@material-ui/icons";
import {DcsTraceDialog} from "../../../components/dcs_config/DcsTraceDialog";
import {StatusIndicator} from "../../../components/generic/StatusIndicator";

export const DcsTraceTab: React.FunctionComponent = observer(() => {
    const model = useModelContext() as DcsConfigModel;

    const [dialogOpen, setDialogOpenTrue, setDialogOpenFalse] = useFlag();
    const [dialogModel, setDialogModel] = React.useState<DcsTraceModel|undefined>(undefined);

    const handleDialogOpen = React.useCallback((model: DcsTraceModel) => {
        setDialogModel(model);
        setDialogOpenTrue();
    }, [])

    const columns = React.useMemo(() => {
        return [
            {
                Header: t`Time - Date`,
                id: 'created_at',
                accessor: (model: DcsTraceModel) => model,
                Cell: (cellInfo: { value: DcsTraceModel }) => {
                    const settings = SystemSettingStore.selectedModel as SystemSettingModel;
                    return (
                        <>
                            {settings ? settings.printTimeDate(cellInfo.value.created_at) : cellInfo.value.created_at}
                        </>
                    )
                }
            },
            makeColumn('job_number', 'Job', 'string'),
            {
                Header: t`Successful?`,
                id: 'error',
                accessor: (model: DcsTraceModel) => model,
                Cell: (cellInfo: { value: DcsTraceModel }) => {
                    return <StatusIndicator success={cellInfo.value.successful}/>
                }
            },
            {
                Header: t`Error`,
                id: 'error',
                accessor: (model: DcsTraceModel) => model,
                Cell: (cellInfo: { value: DcsTraceModel }) => {
                    const errData = cellInfo.value.resolveErrorData;

                    if(!errData){
                        return null;
                    }

                    return errData['message'] ? errData['message'] : t`Unknown Error.`;
                }
            },
            {
                id: '_actions',
                accessor: (model: DcsTraceModel) => model,
                Cell: (cellInfo: { value: DcsTraceModel }) => {
                    return <ButtonField text={t`View Trace`} color={'primary'} startIcon={<Pageview/>} onClick={()=>{handleDialogOpen(cellInfo.value)}}/>
                }
            },
        ]
    }, [SystemSettingStore.selectedModel]);

    return (
        <div>
            <ModelTable store={DcsTraceStore}
                        columns={columns}
                        defaultFiltered={[{id: 'dcs_config_id', value: model.id}]}
                        defaultSorted={[{id: 'created_at', desc: true}]}
                        showCreateButton={false}
                        noLinkColumns={[]}
                        suppressActionColumn
                        suppressWrapper
                        suppressUserDefaults>
            </ModelTable>
            <DcsTraceDialog model={dialogModel} open={dialogOpen} handleClose={setDialogOpenFalse}/>
        </div>
    )
});
