import * as React from "react";
import {observer} from "mobx-react-lite";
import {
    FormProps,
    MachinePicker,
    ModelCheckbox,
    ModelForm,
    ModelInput,
    ModelSelect,
} from "@rx-suite/ui";
import {Box, LinearProgress} from "@material-ui/core";
import {Dcs2restConfigStore} from "../../stores/Dcs2restConfigStore";
import {MachinePickerStore} from "@rx-suite/stores";

export const MachineConfigForm: React.FunctionComponent<FormProps> = observer(({model}) => {
    Dcs2restConfigStore.getAll();

    if(Dcs2restConfigStore.isLoading || MachinePickerStore.isLoading) {
        return <LinearProgress/>
    }

    const dcs2RestOptions = Dcs2restConfigStore.models.map((config) => {
        return {label: config.name, value: config.id}
    })

    return <ModelForm model={model} suppressImportExport suppressMakeCopy suppressFormWrapper suppressWrapper>
        <MachinePicker
            onChange={(name: string | undefined, value: any) => model.nestedAssignment('rx_data_machine_id', value)}
            value={model.viewModel.rx_data_machine_id}
        />
        <ModelInput name={'ip_address'}/>
        <ModelSelect name={'dcs2rest_config_id'} options={dcs2RestOptions}/>
        <Box>
            <ModelCheckbox name={'keep_call_trace'}/>
        </Box>
    </ModelForm>
})
