import {attribute, DataStore, Model, model} from '@rx-suite/data';
import * as yup from 'yup';
import { t } from "@lingui/macro"
import {action, runInAction} from "mobx";

@model({
    transportLayer: "/api/dcs2rest_settings",
    permissionTarget: "Dcs2restSetting",
    singleton: true,
    routingInfo: {
        update: '/settings/dcs2rest'
    }
})
export class Dcs2restSettingModel extends Model {
    @attribute({
        label: t`Server port`,
        validation: yup.number().positive()
    })
    port: number = 3101;

    @attribute({
        label: t`Maximum Traces per Machine`,
        validation: yup.number().min(0).nullable(undefined)
    })
    max_dcs_trace_count: number = 1000;

    @attribute({
        label: t`Enable Dcs2Rest Server?`,
        validation: yup.boolean()
    })
    enable_server: boolean = false;

    @attribute({
        label: t`Server Online?`,
        validation: yup.boolean()
    })
    server_online: boolean = false;

    @action.bound
    async startDcs2RestServer(): Promise<void> {
        const response = await Dcs2restSettingStore.transportLayer.fetch(`/start_server`, {method: "put"});
        const data = await response.json();
        runInAction(() => {
            const model = this.store.createModel(data);
            this.store.setModel(model);
        })
    }

    @action.bound
    async stopDcs2RestServer(): Promise<void> {
        const response = await Dcs2restSettingStore.transportLayer.fetch(`/stop_server`, {method: "put"});
        const data = await response.json();
        runInAction(() => {
            const model = this.store.createModel(data);
            this.store.setModel(model);
        })
    }

    constructor() {
        super();
        super.setup();
    }
}

export const Dcs2restSettingStore = Dcs2restSettingModel.store as DataStore<Dcs2restSettingModel>;
