import {attribute, DataStore, Model, model} from "@rx-suite/data";
import {t} from "@lingui/macro";
import * as yup from "yup";

@model({
    transportLayer: "/api/machine_configs",
    routingInfo: {
        create: '/dcs2rest/machine_config/create',
        update: '/dcs2rest/machine_config/:id/edit'
    }
})
export class MachineConfigModel extends Model {
    @attribute({
        label: t`Machine IP Address`,
        validation: yup.string().matches(/^(?:[0-9]{1,3}\.){3}[0-9]{1,3}$/, t`Must be an ip address`).required()
    })
    ip_address: string = '';

    @attribute({
        validation: yup.number().typeError(t`Machine is a required field`)
    })
    rx_data_machine_id: number | null = null;

    @attribute({
        label: t`Translation Interface`,
        validation: yup.number().typeError(t`Translation Interface is a required field`)
    })
    dcs2rest_config_id: number | null = null;

    @attribute({
        label: t`Keep Call Trace?`,
        validation: yup.boolean().required()
    })
    keep_call_trace: boolean = false;

    constructor() {
        super();
        super.setup();
    }
}
export const MachineConfigStore = MachineConfigModel.store as DataStore<MachineConfigModel>;
