class InterfaceConfig < RxModule::ApplicationRecord
  belongs_to :dcs2rest_config

  concerning :SelectInterface do

    class_methods do
      def select_interface(machine_config, data)
        x_status = extract_xstatus(data)
        session_type = extract_session_type(data)

        if x_status
          machine_config.dcs2rest_config
                        .interface_configs
                        .where(x_status: x_status)
                        .where(type: session_type_to_possible_interfaces[session_type]).first
        else
          Dcs2restServer.log "Request with no XSTATUS, assuming it's process parameter request"
          # The only message that does not have an XSTATUS is the process parameter message
          machine_config.dcs2rest_config.interface_configs.where(type: 'ProcessParameterInterfaceConfig').first
        end
      end

      private

      def extract_xstatus(data)
        line = data.find {|msg| msg.include? 'XSTATUS'}

        return nil if line.nil?

        line = line.split('=')[1]
        line.split(';')[1]
      end

      def extract_session_type(data)
        line = data.find {|msg| msg.include? 'REQ'}

        return nil if line.nil?

        line.split('=')[1]
      end

      def session_type_to_possible_interfaces
        {
          'MNT' => [
            MachineStateInterfaceConfig.name,
            ErrorInterfaceConfig.name,
            MaintenanceInterfaceConfig.name,
            CalibrationInterfaceConfig.name
          ],
          'INF' => [
            JobStateInterfaceConfig.name,
            EventInterfaceConfig.name
          ],
          'INS' => [
            ProcessParameterInterfaceConfig.name
          ]
        }
      end
    end
  end

  concerning :DcsToXml do
    def dcs_to_xml(dcs_data)
      # Takes the arguments provided within the interface class and associates them to values from the message from the client
      arguments = DcsMessageParser.process_arguments(arguments_to_read, dcs_data)
      # Add arguments provided by the data of the interface config itself. ex: {type:1, status:2}
      add_data_arguments(arguments)
      xml = build_xml(arguments)
      # Not all of the xml can be built easily without the client, this adds extra more complex nodes
      add_extra_xml_nodes(xml, dcs_data)
    end

    private

    def base_xml
      Nokogiri::XML('<?xml version = "1.0" encoding = "UTF-8" standalone ="true">')
    end

    def add_data_arguments(args_hash)
      args_hash.merge! JSON.parse(data)
    end

    def add_extra_xml_nodes(xml, data)
      xml
    end

    def arguments_to_read
      # arguments to read from the message, format:
      # [
      #     make_parameter_config_hash()
      # ]
      raise NotImplementedError
    end

    def endpoint
      raise NotImplementedError
    end

    def make_parameter_config_hash(name, message, separator, split_index, required=false, param_list_definition = {})
      {
        name: name,
        message: message,
        separator: separator,
        split_index: split_index,
        required: required,
        param_list_definition: param_list_definition
      }
    end
  end
end

require_dependency 'interface_config_types/job_state_interface_config'
require_dependency 'interface_config_types/process_parameter_interface_config'
require_dependency 'interface_config_types/machine_state_interface_config'
require_dependency 'interface_config_types/event_interface_config'
require_dependency 'interface_config_types/error_interface_config'
require_dependency 'interface_config_types/maintenance_interface_config'
require_dependency 'interface_config_types/calibration_interface_config'